@@ -76,6 +76,7 @@ class SchemaFileFormat(proto.Enum):
 
 class OracleProfile(proto.Message):
     r"""Oracle database profile.
+
     Attributes:
         hostname (str):
             Required. Hostname for the Oracle connection.
@@ -102,6 +103,7 @@ class OracleProfile(proto.Message):
 
 class MysqlProfile(proto.Message):
     r"""MySQL database profile.
+
     Attributes:
         hostname (str):
             Required. Hostname for the MySQL connection.
@@ -126,6 +128,7 @@ class MysqlProfile(proto.Message):
 
 class GcsProfile(proto.Message):
     r"""Cloud Storage bucket profile.
+
     Attributes:
         bucket_name (str):
             Required. The full project and resource path
@@ -140,15 +143,18 @@ class GcsProfile(proto.Message):
 
 
 class NoConnectivitySettings(proto.Message):
-    r"""No connectivity settings.    """
+    r"""No connectivity settings.
+    """
 
 
 class StaticServiceIpConnectivity(proto.Message):
-    r"""Static IP address connectivity.    """
+    r"""Static IP address connectivity.
+    """
 
 
 class ForwardSshTunnelConnectivity(proto.Message):
     r"""Forward SSH Tunnel connectivity.
+
     Attributes:
         hostname (str):
             Required. Hostname for the SSH tunnel.
@@ -232,6 +238,7 @@ class PrivateConnection(proto.Message):
 
 class PrivateConnectivity(proto.Message):
     r"""Private Connectivity
+
     Attributes:
         private_connection_name (str):
 
@@ -273,6 +280,7 @@ class Route(proto.Message):
 
 class MysqlSslConfig(proto.Message):
     r"""MySQL SSL configuration information.
+
     Attributes:
         client_key (str):
             Input only. PEM-encoded private key associated with the
@@ -308,6 +316,7 @@ class MysqlSslConfig(proto.Message):
 
 class ConnectionProfile(proto.Message):
     r"""
+
     Attributes:
         name (str):
             Output only. The resource's name.
@@ -375,6 +384,7 @@ class ConnectionProfile(proto.Message):
 
 class OracleColumn(proto.Message):
     r"""Oracle Column.
+
     Attributes:
         column_name (str):
             Column name.
@@ -412,6 +422,7 @@ class OracleColumn(proto.Message):
 
 class OracleTable(proto.Message):
     r"""Oracle table.
+
     Attributes:
         table_name (str):
             Table name.
@@ -429,6 +440,7 @@ class OracleTable(proto.Message):
 
 class OracleSchema(proto.Message):
     r"""Oracle schema.
+
     Attributes:
         schema_name (str):
             Schema name.
@@ -442,6 +454,7 @@ class OracleSchema(proto.Message):
 
 class OracleRdbms(proto.Message):
     r"""Oracle database structure.
+
     Attributes:
         oracle_schemas (Sequence[google.cloud.datastream_v1alpha1.types.OracleSchema]):
             Oracle schemas/databases in the database
@@ -455,6 +468,7 @@ class OracleRdbms(proto.Message):
 
 class OracleSourceConfig(proto.Message):
     r"""Oracle data source configuration
+
     Attributes:
         allowlist (google.cloud.datastream_v1alpha1.types.OracleRdbms):
             Oracle objects to include in the stream.
@@ -468,6 +482,7 @@ class OracleSourceConfig(proto.Message):
 
 class MysqlColumn(proto.Message):
     r"""MySQL Column.
+
     Attributes:
         column_name (str):
             Column name.
@@ -502,6 +517,7 @@ class MysqlColumn(proto.Message):
 
 class MysqlTable(proto.Message):
     r"""MySQL table.
+
     Attributes:
         table_name (str):
             Table name.
@@ -517,6 +533,7 @@ class MysqlTable(proto.Message):
 
 class MysqlDatabase(proto.Message):
     r"""MySQL database.
+
     Attributes:
         database_name (str):
             Database name.
@@ -530,6 +547,7 @@ class MysqlDatabase(proto.Message):
 
 class MysqlRdbms(proto.Message):
     r"""MySQL database structure
+
     Attributes:
         mysql_databases (Sequence[google.cloud.datastream_v1alpha1.types.MysqlDatabase]):
             Mysql databases on the server
@@ -542,6 +560,7 @@ class MysqlRdbms(proto.Message):
 
 class MysqlSourceConfig(proto.Message):
     r"""MySQL source configuration
+
     Attributes:
         allowlist (google.cloud.datastream_v1alpha1.types.MysqlRdbms):
             MySQL objects to retrieve from the source.
@@ -555,6 +574,7 @@ class MysqlSourceConfig(proto.Message):
 
 class SourceConfig(proto.Message):
     r"""The configuration of the stream source.
+
     Attributes:
         source_connection_profile_name (str):
             Required. Source connection profile
@@ -581,11 +601,13 @@ class SourceConfig(proto.Message):
 
 
 class AvroFileFormat(proto.Message):
-    r"""AVRO file format configuration.    """
+    r"""AVRO file format configuration.
+    """
 
 
 class JsonFileFormat(proto.Message):
     r"""JSON file format configuration.
+
     Attributes:
         schema_file_format (google.cloud.datastream_v1alpha1.types.SchemaFileFormat):
             The schema file format along JSON data files.
@@ -605,6 +627,7 @@ class JsonFileFormat(proto.Message):
 
 class GcsDestinationConfig(proto.Message):
     r"""Google Cloud Storage destination configuration
+
     Attributes:
         path (str):
             Path inside the Cloud Storage bucket to write
@@ -641,6 +664,7 @@ class GcsDestinationConfig(proto.Message):
 
 class DestinationConfig(proto.Message):
     r"""The configuration of the stream destination.
+
     Attributes:
         destination_connection_profile_name (str):
             Required. Destination connection profile
@@ -660,6 +684,7 @@ class DestinationConfig(proto.Message):
 
 class Stream(proto.Message):
     r"""
+
     Attributes:
         name (str):
             Output only. The stream's name.
@@ -725,7 +750,8 @@ class Stream(proto.Message):
     class BackfillNoneStrategy(proto.Message):
         r"""Backfill strategy to disable automatic backfill for the
         Stream's objects.
-            """
+
+        """
 
     name = proto.Field(proto.STRING, number=1,)
     create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
@@ -754,6 +780,7 @@ class Stream(proto.Message):
 
 class Error(proto.Message):
     r"""Represent a user-facing Error.
+
     Attributes:
         reason (str):
             A title that explains the reason for the
@@ -780,6 +807,7 @@ class Error(proto.Message):
 
 class ValidationResult(proto.Message):
     r"""Contains the current validation results.
+
     Attributes:
         validations (Sequence[google.cloud.datastream_v1alpha1.types.Validation]):
             A list of validations (includes both executed
@@ -791,6 +819,7 @@ class ValidationResult(proto.Message):
 
 class Validation(proto.Message):
     r"""
+
     Attributes:
         description (str):
             A short description of the validation.
@@ -817,6 +846,7 @@ class Validation(proto.Message):
 
 class ValidationMessage(proto.Message):
     r"""Represent user-facing validation result message.
+
     Attributes:
         message (str):
             The result of the validation.
